@@ -4,18 +4,17 @@ test_that("append_height", {
   srtmfile <- system.file("extdata/fortaleza-srtm.tif", package="gtfs2gps")
   
   gtfs <- read_gtfs(fortaleza) %>%
-    filter_week_days() %>%
+    filter_by_shape_id("shape804-I") %>%
     filter_single_trip() %>% 
     remove_invalid()
   
-  fortaleza_gps <- gtfs2gps(gtfs, spatial_resolution = 50) %>% append_height(srtmfile)
+  fortaleza_gps <- gtfs2gps(gtfs, spatial_resolution = 500) %>% append_height(srtmfile)
 
   mysum <- sum(fortaleza_gps$height)
-  if(mysum < 70000) mysum <- mysum + 3852
+
+  expect_equal(mysum, 3314, 0.05)
   
-  expect_equal(mysum, 73188, 0.05)
-  
-  fort <- fortaleza_gps[which(is.na(fortaleza_gps$height)),]
+  #fort <- fortaleza_gps[which(is.na(fortaleza_gps$height)),]
   
   #fott <- gps_as_sf(fort)
   #sf::write_sf(fott, "fort-na.shp")  
